@@ -1,6 +1,5 @@
 from __future__ import annotations
 
-import asyncio
 import copy
 import getpass
 import inspect
@@ -9,6 +8,7 @@ import random
 import sys
 import time
 import webbrowser
+from types import ModuleType
 from typing import TYPE_CHECKING, Any, AnyStr, Callable, Dict, List, Optional, Tuple
 
 import anyio
@@ -23,10 +23,12 @@ from gradio.utils import component_or_layout_class, delete_none
 set_documentation_group("blocks")
 
 if TYPE_CHECKING:  # Only import for type checking (is False at runtime).
+    import comet_ml
+    import mlflow
+    import wandb
     from fastapi.applications import FastAPI
 
     from gradio.components import Component, StatusTracker
-    from gradio.routes import PredictBody
 
 
 class Block:
@@ -162,6 +164,11 @@ class BlockContext(Block):
         render: bool = True,
         **kwargs,
     ):
+        """
+        Parameters:
+            visible: If False, this will be hidden but included in the Blocks config file (its visibility can later be updated).
+            render: If False, this will not be included in the Blocks config file at all.
+        """
         self.children = []
         super().__init__(visible=visible, render=render, **kwargs)
 
@@ -226,16 +233,21 @@ def skip() -> dict:
 @document()
 class Blocks(BlockContext):
     """
-    The Blocks class is a low-level API that allows you to create custom web
-    applications entirely in Python. Compared to the Interface class, Blocks offers
-    more flexibility and control over: (1) the layout of components (2) the events that
+    Blocks is Gradio's low-level API that allows you to create more custom web
+    applications and demos than Interfaces (yet still entirely in Python).
+
+
+    Compared to the Interface class, Blocks offers more flexibility and control over:
+    (1) the layout of components (2) the events that
     trigger the execution of functions (3) data flows (e.g. inputs can trigger outputs,
     which can trigger the next level of outputs). Blocks also offers ways to group
-    together related demos e.g. using tabs.
+    together related demos such as with tabs.
+
 
     The basic usage of Blocks is as follows: create a Blocks object, then use it as a
     context (with the "with" statement), and then define layouts, components, or events
     within the Blocks context. Finally, call the launch() method to launch the demo.
+
     Example:
         import gradio as gr
         def update(name):
@@ -299,7 +311,10 @@ class Blocks(BlockContext):
         self.mode = mode
 
         self.is_running = False
+        self.local_url = None
         self.share_url = None
+        self.width = None
+        self.height = None
 
         self.ip_address = utils.get_local_ip_address()
         self.is_space = True if os.getenv("SYSTEM") == "spaces" else False
@@ -739,7 +754,8 @@ class Blocks(BlockContext):
     ) -> Tuple[FastAPI, str, str]:
         """
         Launches a simple web server that serves the demo. Can also be used to create a
-        shareable link.
+        public link used by anyone to access the demo from their browser by setting share=True.
+
         Parameters:
             inline: whether to display in the interface inline in an iframe. Defaults to True in python notebooks; False otherwise.
             inbrowser: whether to automatically launch the interface in a new tab on the default browser.
@@ -771,7 +787,7 @@ class Blocks(BlockContext):
             def reverse(text):
                 return text[::-1]
             demo = gr.Interface(reverse, "text", "text")
-            demo.launch(share=True)
+            demo.launch(share=True, auth=("username", "password"))
         """
         self.dev_mode = False
         if (
@@ -924,6 +940,60 @@ class Blocks(BlockContext):
 
         return self.server_app, self.local_url, self.share_url
 
+    def integrate(
+        self,
+        comet_ml: comet_ml.Experiment = None,
+        wandb: ModuleType("wandb") = None,
+        mlflow: ModuleType("mlflow") = None,
+    ) -> None:
+        """
+        A catch-all method for integrating with other libraries. This method should be run after launch()
+        Parameters:
+            comet_ml: If a comet_ml Experiment object is provided, will integrate with the experiment and appear on Comet dashboard
+            wandb: If the wandb module is provided, will integrate with it and appear on WandB dashboard
+            mlflow: If the mlflow module  is provided, will integrate with the experiment and appear on ML Flow dashboard
+        """
+        analytics_integration = ""
+        if comet_ml is not None:
+            analytics_integration = "CometML"
+            comet_ml.log_other("Created from", "Gradio")
+            if self.share_url is not None:
+                comet_ml.log_text("gradio: " + self.share_url)
+                comet_ml.end()
+            else:
+                comet_ml.log_text("gradio: " + self.local_url)
+                comet_ml.end()
+        if wandb is not None:
+            analytics_integration = "WandB"
+            if self.share_url is not None:
+                wandb.log(
+                    {
+                        "Gradio panel": wandb.Html(
+                            '<iframe src="'
+                            + self.share_url
+                            + '" width="'
+                            + str(self.width)
+                            + '" height="'
+                            + str(self.height)
+                            + '" frameBorder="0"></iframe>'
+                        )
+                    }
+                )
+            else:
+                print(
+                    "The WandB integration requires you to "
+                    "`launch(share=True)` first."
+                )
+        if mlflow is not None:
+            analytics_integration = "MLFlow"
+            if self.share_url is not None:
+                mlflow.log_param("Gradio Interface Share Link", self.share_url)
+            else:
+                mlflow.log_param("Gradio Interface Local Link", self.local_url)
+        if self.analytics_enabled and analytics_integration:
+            data = {"integration": analytics_integration}
+            utils.integration_analytics(data)
+
     def close(self, verbose: bool = True) -> None:
         """
         Closes the Interface that was launched and frees the port.
