@@ -5,12 +5,9 @@ including various methods for constructing an interface and then launching it.
 
 from __future__ import annotations
 
-import copy
-import csv
 import inspect
 import json
 import os
-import random
 import re
 import warnings
 import weakref
@@ -45,18 +42,23 @@ if TYPE_CHECKING:  # Only import for type checking (is False at runtime).
     import transformers
 
 
-@document("launch", "load", "from_pipeline")
+@document("launch", "load", "from_pipeline", "integrate")
 class Interface(Blocks):
     """
-    The Interface class is a high-level abstraction that allows you to create a
-    web-based demo around a machine learning model or arbitrary Python function
-    by specifying: (1) the function (2) the desired input components and (3) desired output components.
+    The Interface class is Gradio's main high-level abstraction, and allows you to create a
+    web-based GUI / demo around a machine learning model (or any Python function). You must specify
+    three parameters: (1) the function to create a GUI for (2) the desired input components and
+    (3) the desired output components. Further parameters can be specified to control the appearance
+    and behavior of the demo.
+
     Example:
         import gradio as gr
+
         def image_classifier(inp):
             return {'cat': 0.3, 'dog': 0.7}
+
         demo = gr.Interface(fn=image_classifier, inputs="image", outputs="label")
-        demo.launch(share=True)
+        demo.launch()
     Demos: hello_world, hello_world_3, gpt_j
     """
 
@@ -722,59 +724,6 @@ class Interface(Blocks):
             self.process(raw_input)
             print("PASSED")
 
-    def integrate(self, comet_ml=None, wandb=None, mlflow=None) -> None:
-        """
-        A catch-all method for integrating with other libraries.
-        Should be run after launch()
-        Parameters:
-            comet_ml (Experiment): If a comet_ml Experiment object is provided,
-            will integrate with the experiment and appear on Comet dashboard
-            wandb (module): If the wandb module is provided, will integrate
-            with it and appear on WandB dashboard
-            mlflow (module): If the mlflow module  is provided, will integrate
-            with the experiment and appear on ML Flow dashboard
-        """
-        analytics_integration = ""
-        if comet_ml is not None:
-            analytics_integration = "CometML"
-            comet_ml.log_other("Created from", "Gradio")
-            if self.share_url is not None:
-                comet_ml.log_text("gradio: " + self.share_url)
-                comet_ml.end()
-            else:
-                comet_ml.log_text("gradio: " + self.local_url)
-                comet_ml.end()
-        if wandb is not None:
-            analytics_integration = "WandB"
-            if self.share_url is not None:
-                wandb.log(
-                    {
-                        "Gradio panel": wandb.Html(
-                            '<iframe src="'
-                            + self.share_url
-                            + '" width="'
-                            + str(self.width)
-                            + '" height="'
-                            + str(self.height)
-                            + '" frameBorder="0"></iframe>'
-                        )
-                    }
-                )
-            else:
-                print(
-                    "The WandB integration requires you to "
-                    "`launch(share=True)` first."
-                )
-        if mlflow is not None:
-            analytics_integration = "MLFlow"
-            if self.share_url is not None:
-                mlflow.log_param("Gradio Interface Share Link", self.share_url)
-            else:
-                mlflow.log_param("Gradio Interface Local Link", self.local_url)
-        if self.analytics_enabled and analytics_integration:
-            data = {"integration": analytics_integration}
-            utils.integration_analytics(data)
-
 
 @document()
 class TabbedInterface(Blocks):
